"""To customize any of the values below,
use settings.DASHBOARD_BASE_TEMPLATES.
"""

dashboard_templates = dict(
    edc_base_template="edc_dashboard/base.html",
    edc_listboard_template="edc_dashboard/listboard.html",
)
